pub(crate) struct DeferredBufferMapping {
pub buffer: Buffer,
pub mode: MapMode,
pub offset: u64,
pub size: NonZeroU64,
pub callback: BufferMapCallback,
}Expand description
A deferred buffer mapping request captured during encoding (or a pass) and executed later when the command buffer is submitted.
Fields
buffer: Buffermode: MapModeoffset: u64size: NonZeroU64callback: BufferMapCallbackAuto Trait Implementations
impl Freeze for DeferredBufferMapping
impl !RefUnwindSafe for DeferredBufferMapping
impl Send for DeferredBufferMapping
impl !Sync for DeferredBufferMapping
impl Unpin for DeferredBufferMapping
impl !UnwindSafe for DeferredBufferMapping